package mdbwhileloop;

import java.io.*;
import java.net.*;

import javax.jms.Message;
import javax.jms.QueueConnection;
import javax.jms.QueueConnectionFactory;
import javax.jms.QueueSender;
import javax.jms.QueueSession;
import javax.jms.Session;
import javax.naming.InitialContext;
import javax.servlet.*;
import javax.servlet.http.*;

/**
 *
 * @author bhavanishankar@dev.java.net
 */
public class MessageSender extends HttpServlet {
   
    public static String JMS_QUEUE_FACTORY = "jms/MDBWhileLoopQueueFactory";
    public static String JMS_QUEUE = "jms/MDBWhileLoopQueue";
    
    /** 
    * Processes requests for both HTTP <code>GET</code> and <code>POST</code> methods.
    * @param request servlet request
    * @param response servlet response
    */
    protected void processRequest(HttpServletRequest request, 
            HttpServletResponse response)throws ServletException, IOException {
        String name = request.getParameter("name");
        String msg = (name == null) ? "Hi bhavanishankar" : "Hi " + name;
        response.setContentType("text/html;charset=UTF-8");
        PrintWriter out = response.getWriter();
        try {
            out.println("<html>");
            out.println("<head>");
            out.println("<title>Servlet MessageSender</title>");  
            out.println("</head>");
            out.println("<body>");
            
            if(sendMsgToJMSQueue(msg)) {
                out.println("Successfully sent message <i>"+ msg + 
                        "</i> to the SJSMQ");
            } else {
                out.println("Failed to send message <"+ msg + 
                        "> to the SJSMQ");
            }
            out.println("</body>");
            out.println("</html>");
        } finally { 
            out.close();
        }
    } 

    public boolean sendMsgToJMSQueue(String msg) {
        System.out.println("mdbwhileloop.MessageSender :: " +
                "sendMsgToJMSQueue");
        QueueConnection queueConnection = null;
        QueueSession queueSession = null;
        try {
            InitialContext ic = new InitialContext();
            QueueConnectionFactory qcf = (QueueConnectionFactory)
                    ic.lookup(JMS_QUEUE_FACTORY);
            javax.jms.Queue q = (javax.jms.Queue) ic.lookup(JMS_QUEUE);
            queueConnection =
                    qcf.createQueueConnection();
            queueSession =
                    queueConnection.createQueueSession(
                    false, Session.AUTO_ACKNOWLEDGE);
            QueueSender sender = queueSession.createSender(q);
            queueConnection.start();
            Message message = queueSession.createTextMessage(msg);
            sender.send(message);
            System.out.println("mdbwhileloop.MessageSender :: " +
                    "Message sent to JMS Queue successfully.");
            return true;
        } catch (Exception ex) {
            ex.printStackTrace();
            return false;
        } finally {
            try {
                queueSession.close();
                queueConnection.close();
            } catch (Exception ex) {
                ex.printStackTrace();
            }

        }
    }
    
    // <editor-fold defaultstate="collapsed" desc="HttpServlet methods. Click on the + sign on the left to edit the code.">
    /** 
    * Handles the HTTP <code>GET</code> method.
    * @param request servlet request
    * @param response servlet response
    */
    protected void doGet(HttpServletRequest request, HttpServletResponse response)
    throws ServletException, IOException {
        processRequest(request, response);
    } 

    /** 
    * Handles the HTTP <code>POST</code> method.
    * @param request servlet request
    * @param response servlet response
    */
    protected void doPost(HttpServletRequest request, HttpServletResponse response)
    throws ServletException, IOException {
        processRequest(request, response);
    }

    /** 
    * Returns a short description of the servlet.
    */
    public String getServletInfo() {
        return "Short description";
    }
    // </editor-fold>
}
